@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import os
 import pathlib
+import shutil
 import sys
 import warnings
 from collections.abc import Iterator
@@ -20,6 +21,7 @@ from upath._chain import Chain
 from upath._chain import ChainSegment
 from upath._chain import FSSpecChainParser
 from upath._protocol import compatible_protocol
+from upath.core import UnsupportedOperation
 from upath.core import UPath
 from upath.core import _UPathMixin
 from upath.types import UNSET_DEFAULT
@@ -27,6 +29,7 @@ from upath.types import JoinablePathLike
 from upath.types import PathInfo
 from upath.types import ReadablePath
 from upath.types import ReadablePathLike
+from upath.types import StatResultType
 from upath.types import SupportsPathLike
 from upath.types import WritablePath
 
@@ -194,6 +197,33 @@ class LocalPath(_UPathMixin, pathlib.Path):
     def __open_reader__(self) -> BinaryIO:
         return self.open("rb")
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, UPath):
+            return NotImplemented
+        eq_path = super().__eq__(other)
+        if eq_path is NotImplemented:
+            return NotImplemented
+        return (
+            eq_path
+            and self.protocol == other.protocol
+            and self.storage_options == other.storage_options
+        )
+
+    def __ne__(self, other: object) -> bool:
+        if not isinstance(other, UPath):
+            return NotImplemented
+        ne_path = super().__ne__(other)
+        if ne_path is NotImplemented:
+            return NotImplemented
+        return (
+            ne_path
+            or self.protocol != other.protocol
+            or self.storage_options != other.storage_options
+        )
+
+    def __hash__(self) -> int:
+        return super().__hash__()
+
     if sys.version_info >= (3, 14):
 
         def __open_rb__(self, buffering: int = UNSET_DEFAULT) -> BinaryIO:
@@ -314,6 +344,12 @@ class LocalPath(_UPathMixin, pathlib.Path):
             **fsspec_kwargs,
         )
 
+    def rmdir(self, recursive: bool = UNSET_DEFAULT) -> None:
+        if recursive is UNSET_DEFAULT or not recursive:
+            return super().rmdir()
+        else:
+            shutil.rmtree(self)
+
     if sys.version_info < (3, 14):  # noqa: C901
 
         @overload
@@ -391,17 +427,145 @@ class LocalPath(_UPathMixin, pathlib.Path):
         def info(self) -> PathInfo:
             return _LocalPathInfo(self)
 
-    if sys.version_info < (3, 13):
+    if sys.version_info < (3, 13):  # noqa: C901
 
-        def full_match(self, pattern: str) -> bool:
+        def full_match(
+            self,
+            pattern: str | os.PathLike[str],
+            *,
+            case_sensitive: bool | None = None,
+        ) -> bool:
             # hacky workaround for missing pathlib.Path.full_match in python < 3.13
             # todo: revisit
-            return self.match(pattern)
+            return self.match(
+                pattern,  # type: ignore[arg-type]
+                case_sensitive=case_sensitive,
+            )
 
         @classmethod
         def from_uri(cls, uri: str, **storage_options: Any) -> Self:
             return UPath(uri, **storage_options)  # type: ignore[return-value]
 
+        def is_dir(self, *, follow_symlinks: bool = True) -> bool:
+            if not follow_symlinks:
+                warnings.warn(
+                    f"{type(self).__name__}.is_dir() follow_symlinks=False"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().is_dir()
+
+        def is_file(self, *, follow_symlinks: bool = True) -> bool:
+            if not follow_symlinks:
+                warnings.warn(
+                    f"{type(self).__name__}.is_file() follow_symlinks=False"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().is_file()
+
+        def read_text(
+            self,
+            encoding: str | None = None,
+            errors: str | None = None,
+            newline: str | None = None,
+        ) -> str:
+            if newline is not None:
+                warnings.warn(
+                    f"{type(self).__name__}.read_text() newline"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().read_text(
+                encoding=encoding,
+                errors=errors,
+            )
+
+        def glob(  # type: ignore[override]
+            self,
+            pattern: str | os.PathLike,
+            *,
+            case_sensitive: bool | None = None,
+            recurse_symlinks: bool = False,
+        ) -> Iterator[Self]:
+            if isinstance(pattern, str):
+                pattern_str = pattern
+            else:
+                pattern_str = os.fspath(pattern)
+            kw: dict[str, Any] = {}
+            if case_sensitive is not None:
+                if sys.version_info < (3, 12):
+                    warnings.warn(
+                        f"{type(self).__name__}.glob() case_sensitive"
+                        " is currently ignored.",
+                        UserWarning,
+                        stacklevel=2,
+                    )
+                else:
+                    kw["case_sensitive"] = case_sensitive
+            if recurse_symlinks:
+                warnings.warn(
+                    f"{type(self).__name__}.glob() recurse_symlinks=True"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().glob(pattern_str, **kw)
+
+        def rglob(  # type: ignore[override]
+            self,
+            pattern: str | os.PathLike,
+            *,
+            case_sensitive: bool | None = None,
+            recurse_symlinks: bool = False,
+        ) -> Iterator[Self]:
+            if isinstance(pattern, str):
+                pattern_str = pattern
+            else:
+                pattern_str = os.fspath(pattern)
+            kw: dict[str, Any] = {}
+            if case_sensitive is not None:
+                if sys.version_info < (3, 12):
+                    warnings.warn(
+                        f"{type(self).__name__}.rglob() case_sensitive"
+                        " is currently ignored.",
+                        UserWarning,
+                        stacklevel=2,
+                    )
+                else:
+                    kw["case_sensitive"] = case_sensitive
+            if recurse_symlinks:
+                warnings.warn(
+                    f"{type(self).__name__}.rglob() recurse_symlinks=True"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().rglob(pattern_str, **kw)
+
+        def owner(self, *, follow_symlinks: bool = True) -> str:
+            if not follow_symlinks:
+                warnings.warn(
+                    f"{type(self).__name__}.owner() follow_symlinks=False"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().owner()
+
+        def group(self, *, follow_symlinks: bool = True) -> str:
+            if not follow_symlinks:
+                warnings.warn(
+                    f"{type(self).__name__}.group() follow_symlinks=False"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().group()
+
     if sys.version_info < (3, 12):
 
         def is_junction(self) -> bool:
@@ -416,18 +580,120 @@ class LocalPath(_UPathMixin, pathlib.Path):
             _walk = ReadablePath.walk.__get__(self)
             return _walk(top_down, on_error, follow_symlinks)
 
+        def match(
+            self,
+            path_pattern: str | os.PathLike[str],
+            *,
+            case_sensitive: bool | None = None,
+        ) -> bool:
+            if isinstance(path_pattern, str):
+                pattern_str = path_pattern
+            else:
+                pattern_str = os.fspath(path_pattern)
+            if case_sensitive is not None:
+                warnings.warn(
+                    f"{type(self).__name__}.match() case_sensitive"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().match(pattern_str)
+
+        def exists(self, *, follow_symlinks: bool = True) -> bool:
+            if not follow_symlinks:
+                warnings.warn(
+                    f"{type(self).__name__}.exists() follow_symlinks=False"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().exists()
+
+        def relative_to(  # type: ignore[override]
+            self,
+            other: str | os.PathLike[str],
+            /,
+            *_deprecated: str | os.PathLike[str],
+            walk_up: bool = False,
+        ) -> Self:
+            if walk_up:
+                warnings.warn(
+                    f"{type(self).__name__}.relative_to() walk_up=True"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().relative_to(other, *_deprecated)
+
     if sys.version_info < (3, 10):
 
         def hardlink_to(self, target: ReadablePathLike) -> None:
             try:
                 os.link(target, self)  # type: ignore[arg-type]
             except AttributeError:
-                raise NotImplementedError
+                raise UnsupportedOperation("hardlink operation not supported")
+
+        # let's skip this one as backporting it breaks one pathlib test
+        # @property
+        # def parents(self) -> Sequence[Self]:
+        #     return list(super().parents)
+
+        def stat(  # type: ignore[override]
+            self,
+            *,
+            follow_symlinks: bool = True,
+        ) -> StatResultType:
+            if not follow_symlinks:
+                warnings.warn(
+                    f"{type(self).__name__}.stat() follow_symlinks=False"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().stat()  # type: ignore[return-value]
+
+        def write_text(
+            self,
+            data: str,
+            encoding: str | None = None,
+            errors: str | None = None,
+            newline: str | None = None,
+        ) -> int:
+            if newline is not None:
+                warnings.warn(
+                    f"{type(self).__name__}.write_text() newline"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().write_text(
+                data,
+                encoding=encoding,
+                errors=errors,
+            )
+
+        def chmod(
+            self,
+            mode: int,
+            *,
+            follow_symlinks: bool = True,
+        ) -> None:
+            if not follow_symlinks:
+                warnings.warn(
+                    f"{type(self).__name__}.chmod() follow_symlinks=False"
+                    " is currently ignored.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            return super().chmod(mode)
 
     if not hasattr(pathlib.Path, "_copy_from"):
 
         def _copy_from(
-            self, source: ReadablePath | LocalPath, follow_symlinks: bool = True
+            self,
+            source: ReadablePath | LocalPath,
+            follow_symlinks: bool = True,
+            preserve_metadata: bool = False,
         ) -> None:
             _copy_from: Any = WritablePath._copy_from.__get__(self)
             _copy_from(source, follow_symlinks=follow_symlinks)
@@ -464,7 +730,7 @@ else:
                 chain_parser: FSSpecChainParser = DEFAULT_CHAIN_PARSER,
                 **storage_options: Any,
             ) -> WindowsUPath:
-                raise NotImplementedError(
+                raise UnsupportedOperation(
                     f"cannot instantiate {cls.__name__} on your system"
                 )
 
@@ -480,7 +746,7 @@ else:
                 chain_parser: FSSpecChainParser = DEFAULT_CHAIN_PARSER,
                 **storage_options: Any,
             ) -> PosixUPath:
-                raise NotImplementedError(
+                raise UnsupportedOperation(
                     f"cannot instantiate {cls.__name__} on your system"
                 )
 
@@ -520,5 +786,13 @@ class FilePath(UPath):
     def home(cls) -> Self:
         return cls(os.path.expanduser("~"), protocol="file")
 
+    def chmod(
+        self,
+        mode: int,
+        *,
+        follow_symlinks: bool = True,
+    ) -> None:
+        return os.chmod(self.path, mode, follow_symlinks=follow_symlinks)
+
 
 LocalPath.register(FilePath)
